photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerslideshow.h
branchRCL_3
changeset 25 191387a8b767
parent 22 2dac0fdba72b
--- a/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerslideshow.h	Wed Apr 14 15:57:24 2010 +0300
+++ b/photosgallery/viewframework/commandhandlers/commoncommandhandlers/inc/glxcommandhandlerslideshow.h	Tue Apr 27 16:37:53 2010 +0300
@@ -44,16 +44,18 @@
             public MGlxMediaListObserver
 	{
 public:
     /**
      * Two-phase constructor
      * @param aMediaListProvider object that provides the media list
      * @param aStepBack EFalse if the command handler should not change
      *	 the path's level. E.g. this may depend on whether the view's media 
      *   list contains media items or if it is a "list of lists"
      * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
      */
 	IMPORT_C static CGlxCommandHandlerSlideshow* NewL(
-	    MGlxMediaListProvider* aMediaListProvider, TBool aStepBack, TBool aHasToolbarItem );
+			MGlxMediaListProvider* aMediaListProvider, TBool aStepBack,
+			TBool aHasToolbarItem, const TDesC& aFileName);
 	    
 	/** Destructor */
 	IMPORT_C ~CGlxCommandHandlerSlideshow();
@@ -88,7 +90,7 @@
     
 private:
     /** Second phase constructor */
-	void ConstructL();
+	void ConstructL(const TDesC& aFileName);
 
     /** Constructor */
 	CGlxCommandHandlerSlideshow(MGlxMediaListProvider* aMediaListProvider,
@@ -44,16 +44,18 @@
 	{
 public:
-    /**
-     * Two-phase constructor
-     * @param aMediaListProvider object that provides the media list
-     * @param aStepBack EFalse if the command handler should not change
-     *	 the path's level. E.g. this may depend on whether the view's media 
-     *   list contains media items or if it is a "list of lists"
-     * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
-     */
+	/**
+	 * Two-phase constructor
+	 * @param aMediaListProvider object that provides the media list
+	 * @param aStepBack EFalse if the command handler should not change
+	 *	 the path's level. E.g. this may depend on whether the view's media 
+	 *   list contains media items or if it is a "list of lists"
+	 * @param aHasToolbarItem Whether Command Should be toolbar item (ETrue - if toolbar item)
+	 * @param aFileName resource file
+	 */
 	IMPORT_C static CGlxCommandHandlerSlideshow* NewL(